@@ -18,13 +18,13 @@ from tkinter.filedialog import askopenfilename, askdirectory, asksaveasfilename
 
 from tk_builder.base_elements import StringDescriptor, BooleanDescriptor
 from tk_builder.widgets.image_canvas_tool import ShapeTypeConstants
-from tk_builder.widgets.image_panel_detail import ImagePanelDetail
+from tk_builder.widgets.pyplot_frame import ImagePanelDetail
 from tk_builder.image_reader import CanvasImageReader
 from tk_builder.panels.image_panel import ImagePanel
 
 from tk_builder.widgets.basic_widgets import Frame, Label, Entry, Button, \
     Combobox, Notebook
-from tk_builder.widgets.derived_widgets import TreeviewWithScrolling, TextWithScrolling
+from tk_builder.widgets.derived_widgets import TreeviewWithScrolling, TextWithScrolling, PopupWindow
 from tk_builder.widgets.widget_descriptors import LabelDescriptor, EntryDescriptor, TypedDescriptor
 
 from sarpy_apps.supporting_classes.file_filters import common_use_collection, all_files, json_files
@@ -1165,12 +1165,6 @@ class AnnotationPanel(Frame):
         self.name_panel.save()
         self.tab_panel.save()
 
-    def hide_on_close(self):
-        self.master.protocol("WM_DELETE_WINDOW", self.close_window)
-
-    def close_window(self):
-        self.master.withdraw()
-
 
 ##################
 # Annotation collection panel for display and interaction
@@ -1617,6 +1611,11 @@ class AnnotationTool(PanedWindow, WidgetWithMetadata):
                                                    on_selection_finalized=True,
                                                    fetch_full_resolution=False)
 
+        self.image_panel.canvas.variables.state.line_options.update(
+            {'arrow': tkinter.LAST, 'arrowshape': '9 10 4'})
+        self.image_panel.canvas.variables.state.highlight_line_options.update(
+            {'arrow': tkinter.LAST, 'arrowshape': '10 12 6'})
+
         self.collection_panel = AnnotationCollectionPanel(self, self.variables)
 
         self.add(self.collection_panel, width=200, height=700, padx=3, pady=3, sticky='NSEW')
@@ -1675,10 +1674,8 @@ class AnnotationTool(PanedWindow, WidgetWithMetadata):
         # set up the label_panel viewer event listeners
         self.collection_panel.viewer.bind('<<TreeviewSelect>>', self.feature_selected_on_viewer)
 
-        self.annotate_popup = tkinter.Toplevel(master)
+        self.annotate_popup = PopupWindow(master)
         self.annotate = AnnotationPanel(self.annotate_popup, self.variables)
-        self.annotate.hide_on_close()
-        self.annotate_popup.withdraw()
 
         # bind actions/listeners from annotate popup
         self.annotate.tab_panel.geometry_tab.bind('<<GeometryPropertyChanged>>', self.geometry_selected_on_viewer)
@@ -2093,8 +2090,8 @@ class AnnotationTool(PanedWindow, WidgetWithMetadata):
             # type: () -> (int, str)
             image_coords = the_geometry.coordinates[:, :2].flatten().tolist()
             # create the shape on the annotate panel
-            self.line = self.image_panel.canvas.create_new_line((0, 0, 0, 0), make_current=False,
-                                                                color=geometry_properties.color)
+            self.line = self.image_panel.canvas.create_new_line(
+                (0, 0, 0, 0), make_current=False, color=geometry_properties.color)
             canvas_id = self.line
             self.image_panel.canvas.modify_existing_shape_using_image_coords(
                 canvas_id, image_coords)
@@ -2102,7 +2099,6 @@ class AnnotationTool(PanedWindow, WidgetWithMetadata):
 
         def insert_polygon():
             # type: () -> (int, str)
-
             # this will only render an outer ring
             image_coords = the_geometry.outer_ring.coordinates[:, :2].flatten().tolist()
             # create the shape on the annotate panel
@@ -2378,10 +2374,6 @@ class AnnotationTool(PanedWindow, WidgetWithMetadata):
             return False  # cancel
         return True
 
-    def _set_focus_on_annotation_popup(self):
-        self.annotate_popup.focus_set()
-        self.annotate_popup.lift()
-
     def _set_focus_on_main(self):
         self.master.focus_set()
         self.master.lift()
@@ -2491,8 +2483,7 @@ class AnnotationTool(PanedWindow, WidgetWithMetadata):
         self._set_focus_on_main()
 
     def callback_popup_annotation(self):
-        self.annotate_popup.deiconify()
-        self._set_focus_on_annotation_popup()
+        self.annotate_popup.popup_callback()
 
     def callback_popup_apply(self):
         self.annotate.save()
@@ -2644,7 +2635,7 @@ class AnnotationTool(PanedWindow, WidgetWithMetadata):
         self.set_current_geometry_id(current_geometry_id, check_popup=False)
 
     def detail_popup_callback(self):
-        self.image_panel_detail.set_focus_on_detail_popup()
+        self.image_panel_detail.set_focus_on_popup()
 
 
 def main(reader=None, annotation=None):
